==> nui_form-0.0.59.tar.gz: lib/model/nuif_models.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/component/nuif_text.dart';
import 'package:nui_form/nuif_form.dart';

abstract class NUIFSelection{
  bool selected;
  String getId();
  String getCaption();
  String getValue();

  String getHint() => null;
  bool selectable() => true;
  TextStyle getFontStyle() => null;
  Widget getCustomView() => null;

  NUIFTextItem getOtherTextItem() => null;
}

enum TextValidation{
  LESS_THAN_MIN_LENGTH,
  EXCEED_MAX_LENGTH,
  NOT_FILLED,
  CONTENT_CHECK_FAILED,
  REG_EXPRESSION_FAILED
}

class StandardRegularExp{
  StandardRegularExp._builder();
  static final String EMAIL = "^[a-zA-Z0-9.!#\$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,253}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,253}[a-zA-Z0-9])?)*\$";
  static final String EMAIL2 = "r'^[A-Z0-9a-z._%+-]+@[A-Za-z0-9-]+\.[A-Za-z.-]{2,64}'";
}

class TextAdditionalFormatting{
  TextAdditionalFormatting._builder();

  static bool passwordValidation(NUIFTextItem target, String value, {bool atLeastOneSymbol: true, bool atLeastOneCap: true, bool atLeastOneNumber: true}){
      final symbols = ["~", "!", "@", "#", "\$", "%", "^", "&", "*", "(", ")", "_", "-", "+", ".", ",",":",";","/","\\", "?", "'", ">", "<"];

      final minLength = target.minLength ?? 8;
      final errorMessages = target.errorMessages;
      if (isNullOrEmpty(value)) {
        errorMessages[TextValidation.LESS_THAN_MIN_LENGTH] = "Password must contain be at least $minLength characters";
        return false;
      }
      else {
        var hasSymbol = false;
        for (var s in symbols) {
          if (value.contains(s)) {
            hasSymbol = true;
            break;
          }
        }

        if(value.length < minLength){
          errorMessages[TextValidation.LESS_THAN_MIN_LENGTH] = "Password must contain at least ${target.minLength ?? 8} characters";
          return false;
        }
        else if (value.contains(" ")) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must not contain any spaces";
          return false;
        }
        else if (atLeastOneCap == true && !NUIStringUtil.validateStringPattern(value, "[A-Z]", fullMatch: false)) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must contain at least one upper case";
          return false;
        } else if (atLeastOneNumber == true && !NUIStringUtil.validateStringPattern(value, "[0-9]", fullMatch: false)) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must contain at least one number";
          return false;
        }
        else if (atLeastOneSymbol == true && !hasSymbol) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must contain at least one special character";
          return false;
        }
        else {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Please enter a valid password";
          return true;
        }
      }
  }
}

class NUIFValidatable{
  bool validated;
  bool failed;
  Map<TextValidation, String> errorMessages;

  static Map<TextValidation, String> defaultErrorMessages() => {
    TextValidation.LESS_THAN_MIN_LENGTH: "Minimum length not reached",
    TextValidation.EXCEED_MAX_LENGTH: "Maximum length exceeded",
    TextValidation.NOT_FILLED: "Please fill this in",
    TextValidation.CONTENT_CHECK_FAILED: "Content does not match",
    TextValidation.REG_EXPRESSION_FAILED: "Validation failed"
  };
}

==> nui_form-0.0.61.tar.gz: lib/model/nuif_models.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/component/nuif_text.dart';
import 'package:nui_form/nuif_form.dart';

abstract class NUIFSelection{
  bool selected;
  String getId();
  String getCaption();
  String getValue();

  String getHint() => null;
  bool selectable() => true;
  TextStyle getFontStyle() => null;
  Widget getCustomView() => null;

  NUIFTextItem getOtherTextItem() => null;
}

enum TextValidation{
  LESS_THAN_MIN_LENGTH,
  EXCEED_MAX_LENGTH,
  NOT_FILLED,
  CONTENT_CHECK_FAILED,
  REG_EXPRESSION_FAILED
}

class StandardRegularExp{
  StandardRegularExp._builder();
  static final String EMAIL = "^[a-zA-Z0-9.!#\$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,253}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,253}[a-zA-Z0-9])?)*\$";
  static final String EMAILV2 = r'^[A-Z0-9a-z._%+-]+@[A-Za-z0-9-]+\.[A-Za-z.-]{2,64}';
}

class TextAdditionalFormatting{
  TextAdditionalFormatting._builder();

  static bool passwordValidation(NUIFTextItem target, String value, {bool atLeastOneSymbol: true, bool atLeastOneCap: true, bool atLeastOneNumber: true}){
      final symbols = ["~", "!", "@", "#", "\$", "%", "^", "&", "*", "(", ")", "_", "-", "+", ".", ",",":",";","/","\\", "?", "'", ">", "<"];

      final minLength = target.minLength ?? 8;
      final errorMessages = target.errorMessages;
      if (isNullOrEmpty(value)) {
        errorMessages[TextValidation.LESS_THAN_MIN_LENGTH] = "Password must contain be at least $minLength characters";
        return false;
      }
      else {
        var hasSymbol = false;
        for (var s in symbols) {
          if (value.contains(s)) {
            hasSymbol = true;
            break;
          }
        }

        if(value.length < minLength){
          errorMessages[TextValidation.LESS_THAN_MIN_LENGTH] = "Password must contain at least ${target.minLength ?? 8} characters";
          return false;
        }
        else if (value.contains(" ")) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must not contain any spaces";
          return false;
        }
        else if (atLeastOneCap == true && !NUIStringUtil.validateStringPattern(value, "[A-Z]", fullMatch: false)) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must contain at least one upper case";
          return false;
        } else if (atLeastOneNumber == true && !NUIStringUtil.validateStringPattern(value, "[0-9]", fullMatch: false)) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must contain at least one number";
          return false;
        }
        else if (atLeastOneSymbol == true && !hasSymbol) {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Password must contain at least one special character";
          return false;
        }
        else {
          errorMessages[TextValidation.CONTENT_CHECK_FAILED] = "Please enter a valid password";
          return true;
        }
      }
  }
}

class NUIFValidatable{
  bool validated;
  bool failed;
  Map<TextValidation, String> errorMessages;

  static Map<TextValidation, String> defaultErrorMessages() => {
    TextValidation.LESS_THAN_MIN_LENGTH: "Minimum length not reached",
    TextValidation.EXCEED_MAX_LENGTH: "Maximum length exceeded",
    TextValidation.NOT_FILLED: "Please fill this in",
    TextValidation.CONTENT_CHECK_FAILED: "Content does not match",
    TextValidation.REG_EXPRESSION_FAILED: "Validation failed"
  };
}
